@@ -76,8 +76,6 @@
 #'   \emph{before} calculating frequencies, so those will be impacted
 #'   accordingly.
 #'
-#' @seealso \code{\link[base]{summary.data.frame}}
-#'
 #' @examples
 #' data(tobacco)
 #' dfSummary(tobacco)
@@ -252,16 +250,25 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
       counts <- table(column_data, useNA = "no")
       props <- round(prop.table(counts), round.digits + 2)
 
-
-      if (n_levels <= max.distinct.values) {
+      if (n_levels == 0 && n_valid == 0) {
+        output[i,4] <- "No levels defined"
+        output[i,5] <- "All NA's"
+        output[i,6] <- ""
+        output[i,7] <- ""
+      } else if (n_valid == 0) {
+        output[i,4] <- paste0(1:n_levels,". ", levels(column_data), collapse = "  \n")
+        output[i,5] <- "All NA's"
+        output[i,6] <- ""
+        output[i,7] <- ""
+      } else if (n_levels <= max.distinct.values) {
         output[i,4] <- paste0(1:n_levels,". ", levels(column_data), collapse = "  \n")
         counts_props <- align_numbers(counts, props)
         output[i,5] <- paste(counts_props, collapse = "  \n")
-        output[i,6] <- encode_graph(counts, "barplot")
-        output[i,7] <- txtbarplot(prop.table(counts))
-
+        if (graph.col && any(!is.na(column_data))) {
+          output[i,6] <- encode_graph(counts, "barplot")
+          output[i,7] <- txtbarplot(prop.table(counts))
+        }
       } else {
-
         # more levels than allowed by max.distinct.values
         n_extra_levels <- n_levels - max.distinct.values
         output[i,4] <- paste0(1:max.distinct.values,". ",
@@ -277,16 +284,19 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
           c(props[1:max.distinct.values],
             sum(props[(max.distinct.values + 1):length(props)]))
         )
+        
         output[i,5] <- paste(counts_props, collapse = "  \n")
 
-        # prepare data for barplot
-        tmp_data <- column_data
-        levels(tmp_data)[max.distinct.values + 1] <- paste("[", n_extra_levels, "others", "]")
-        tmp_data[which(as.numeric(tmp_data) > max.distinct.values)] <-
-          paste("[", n_extra_levels, "others", "]")
-        levels(tmp_data)[(max.distinct.values + 2):n_levels] <- NA
-        output[i,6] <- encode_graph(table(tmp_data), "barplot")
-        output[i,7] <- txtbarplot(prop.table(table(tmp_data)))
+        if (graph.col && any(!is.na(column_data))) {
+          # prepare data for barplot
+          tmp_data <- column_data
+          levels(tmp_data)[max.distinct.values + 1] <- paste("[", n_extra_levels, "others", "]")
+          tmp_data[which(as.numeric(tmp_data) > max.distinct.values)] <-
+            paste("[", n_extra_levels, "others", "]")
+          levels(tmp_data)[(max.distinct.values + 2):n_levels] <- NA
+          output[i,6] <- encode_graph(table(tmp_data), "barplot")
+          output[i,7] <- txtbarplot(prop.table(table(tmp_data)))
+        }
       }
 
     } else if (is.character(column_data)) {
@@ -299,15 +309,15 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
       }
 
       if (sum(column_data == "", na.rm = TRUE) == length(column_data)) {
-        output[i,4] <- "All empty strings"
-        output[i,5] <- ""
-        output[i,6] <- NA
+        output[i,4] <- ""
+        output[i,5] <- "All empty strings"
+        output[i,6] <- ""
         output[i,7] <- ""
 
       } else if (n_miss == n_tot) {
         output[i,4] <- "All NA's"
         output[i,5] <- ""
-        output[i,6] <- NA
+        output[i,6] <- ""
         output[i,7] <- ""
 
       } else {
@@ -341,13 +351,15 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
                       sum(props[(max.distinct.values + 1):length(props)])))
           output[i,5] <- paste(counts_props, collapse = "  \n")
 
-          # Prepare data for graph
-          counts[max.distinct.values + 1] <-
-            sum(counts[(max.distinct.values + 1):length(counts)])
-          names(counts)[max.distinct.values + 1] <- paste0("[ ", n_extra_values, " others ]")
-          counts <- counts[1:(max.distinct.values + 1)]
-          output[i,6] <- encode_graph(counts, "barplot")
-          output[i,7] <- txtbarplot(prop.table(counts))
+          if (graph.col) {
+            # Prepare data for graph
+            counts[max.distinct.values + 1] <-
+              sum(counts[(max.distinct.values + 1):length(counts)])
+            names(counts)[max.distinct.values + 1] <- paste0("[ ", n_extra_values, " others ]")
+            counts <- counts[1:(max.distinct.values + 1)]
+            output[i,6] <- encode_graph(counts, "barplot")
+            output[i,7] <- txtbarplot(prop.table(counts))
+          }
         }
       }
 
@@ -355,9 +367,9 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
 
       # For numeric data, display a column of descriptive stats and a column of frequencies
       if (n_miss == n_tot) {
-        output[i,4] <- "All NA's"
-        output[i,5] <- ""
-        output[i,6] <- NA
+        output[i,4] <- ""
+        output[i,5] <- "All NA's"
+        output[i,6] <- ""
         output[i,7] <- ""
       } else {
         output[i,4] <- paste(
@@ -373,6 +385,7 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
         )
 
         counts <- table(column_data, useNA = "no")
+        extra_space <- FALSE
 
         if (length(counts) <= max.distinct.values &&
             all(abs(as.numeric(names(counts))) >= 0.01)) {
@@ -386,25 +399,25 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
           if (any(names(counts) != roundval)) {
             extra_space <- TRUE
             output[i,5] <- paste(output[i,5], "! rounded", sep = "  \n")
-          } else {
-            extra_space <- FALSE
-          }
+          } 
         } else {
           output[i,5] <- paste(length(counts), "distinct val.")
         }
 
-        if (length(counts) <= max.distinct.values) {
-          output[i,6] <- encode_graph(counts, "barplot")
-          if (isTRUE(extra_space)) {
-            output[i,6] <- paste0(output[i,6], "  \n\n")
+        if (graph.col) {
+          if (length(counts) <= max.distinct.values) {
+            output[i,6] <- encode_graph(counts, "barplot")
+            if (isTRUE(extra_space)) {
+              output[i,6] <- paste0(output[i,6], "  \n\n")
+            }
+            output[i,7] <- txtbarplot(prop.table(counts))
+          } else {
+            output[i,6] <- encode_graph(column_data, "histogram")
+            output[i,7] <- txthist(column_data)
           }
-          output[i,7] <- txtbarplot(prop.table(counts))
-        } else {
-          output[i,6] <- encode_graph(column_data, "histogram")
-          output[i,7] <- txthist(column_data)
         }
       }
-
+      
     } else {
 
       # Data does not fit in previous categories (neither numeric, character, or factor)
@@ -412,9 +425,9 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
       counts <- table(column_data, useNA = "no")
 
       if (n_miss == n_tot) {
-        output[i,4] <- "Contains only NA's"
-        output[i,5] <- ""
-        output[i,6] <- NA
+        output[i,4] <- ""
+        output[i,5] <- "All NA's"
+        output[i,6] <- ""
         output[i,7] <- ""
 
       } else if (length(counts) <= max.distinct.values) {
@@ -425,7 +438,7 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
       } else {
         output[i,5] <- paste(as.character(length(unique(column_data))), "distinct val.")
       }
-      output[i,6] <- NA
+      output[i,6] <- ""
       output[i,7] <- ""
     }
 
@@ -448,7 +461,7 @@ dfSummary <- function(x, round.digits = 2, varnumbers = TRUE,
     output$Graph <- NULL
     output[['Text Graph']] <- NULL
   }
-  
+
   # Set output attributes
   class(output) <- c("summarytools", class(output))
   attr(output, "st_type") <- "dfSummary"
